Command line tools
=====================

.. note:: 

   You can access the help of any tools as `agox --help` or `agox <subcommand> --help`. 

AGOX comes with a set of CLI tools that can be invoked using the command :code:`agox`. 
Specifically 

- :code:`agox analysis`: For analysing searches
- :code:`agox convert`: For converting AGOX database files to ASE trajectories.
- :code:`agox graph-sort`: For filtering structures based on the Voronoi graph representation. 
- :code:`agox plot`: For plotting structures.

See the pages below for information about each individual tool.

.. toctree::
   :maxdepth: 1

   agox_analysis
   agox_convert
   agox_graph
   agox_plot


